about summary refs log tree commit diff
path: root/src/supplicant/nm-supplicant-config.c
diff options
context:
space:
mode:
authorSebastien Bacher <seb128@ubuntu.com>2020-01-07 16:53:57 +0100
committerSebastien Bacher <seb128@ubuntu.com>2020-01-07 16:56:18 +0100
commit5035d260cb1cde38bfdc732e0d1ff8b3ca78135c (patch)
tree1433995e753effc7cfa4f63266691bdc8b5ad6b3 /src/supplicant/nm-supplicant-config.c
parent21add8edb7927d06f038208fd6271202063d5293 (diff)
parent121343423a2e75e15e16988e664a8b32a629f2ba (diff)
Merge tag 'debian/1.20.6-1'
network-manager Debian release 1.20.6-1
Diffstat (limited to 'src/supplicant/nm-supplicant-config.c')
-rw-r--r--src/supplicant/nm-supplicant-config.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/supplicant/nm-supplicant-config.c b/src/supplicant/nm-supplicant-config.c
index f6e3c7da..a5a68070 100644
--- a/src/supplicant/nm-supplicant-config.c
+++ b/src/supplicant/nm-supplicant-config.c
@@ -881,8 +881,8 @@ nm_supplicant_config_add_setting_wireless_security (NMSupplicantConfig *self,
 		}
 	}
 
-	/* Don't try to enable PMF on non-WPA networks */
-	if (!NM_IN_STRSET (key_mgmt, "wpa-eap", "wpa-psk"))
+	/* Don't try to enable PMF on non-WPA/SAE networks */
+	if (!NM_IN_STRSET (key_mgmt, "wpa-eap", "wpa-psk", "sae"))
 		pmf = NM_SETTING_WIRELESS_SECURITY_PMF_DISABLE;
 
 	/* Check if we actually support PMF */